
Program GroupProject;
uses graph,crt;
CONST
   clear = 20;
   Left = true;
   Right = false;
   IntMapWidth = 47;
   IntMapHeight = 33;
   FileNameLen = 12;

TYPE
   IntMapField = PACKED ARRAY [0..IntMapWidth, 0..IntMapHeight] OF char;
   FileType = PACKED ARRAY [1..FileNameLen] OF char;

PROCEDURE LoadIntMap(FileName : FileType; VAR IntMap : IntMapField;
                     VAR width, height : integer);
   VAR
      hFile : text;
      x, y, color : integer;
      LCV : integer;
      nElements : integer;
   BEGIN
      (*  Initialize all elements to clear  *)
      FOR x := 0 TO IntMapWidth DO
         FOR y := 0 TO IntMapHeight DO
            IntMap[x, y] := chr(clear);

      (*  Open IntMap file and read the number of elements  *)
      assign(hFile, FileName);
      reset(hFile);
      read(hFile, width);
      readln(hFile, height);

      (*  Read the IntMap into memory  *)
      FOR y := 0 TO height DO
         BEGIN
            FOR x := 0 TO width DO
               BEGIN
                  read(hFile, color);
                  IF color <> clear THEN
                     IntMap[x, y] := chr(color);
               END;
            readln(hFile);
         END;

      (*  Close the IntMap  *)
      close(hFile);
   END;

PROCEDURE PasteIntMap(x, y, w, h : integer; IntMap : IntMapField; ScreenIntMap : IntMapField);
   VAR
      IntMapColor, ScreenMapColor, ScreenColor : integer;
      LCV : integer;
      curx, cury : integer;
   BEGIN
      (*  Loop through all the pixels in the replacement IntMap  *)
      FOR curx := 0 TO w DO
         FOR cury := 0 TO h DO
            BEGIN
               (*  Initialize color values  *)
               IntMapColor := ord(IntMap[curx, cury]);
               ScreenColor := getpixel(x + curx, y + cury);
               ScreenMapColor := ord(ScreenIntMap[curx, cury]);

               (*  If the screen color is not what is needs to be, change it  *)
               IF (ScreenColor <> IntMapColor) OR
                  (ScreenColor <> ScreenMapColor) THEN
                  IF IntMapColor = clear THEN
                     putpixel(x + curx, y + cury, ScreenMapColor)
                  ELSE
                     putpixel(x + curx, y + cury, IntMapColor);
            END;
   END;

PROCEDURE EraseRegion(x, y, w, h : integer; ScreenIntMap : IntMapField);
   VAR
      curx, cury : integer;
   BEGIN
      (*  Load the ScreenIntMap into the region given  *)
      FOR curx := 0 TO w DO
         FOR cury := 0 TO h DO
            IF (getpixel(x + curx, y + cury) <> ord(ScreenIntMap[curx, cury])) THEN
               putpixel(curx + x, cury + y, ord(ScreenIntMap[curx, cury]));
   END;

PROCEDURE ClippedEraseRegion(x, y, w, h, cx, cy, cw, ch : integer; ScreenIntMap : IntMapField);
   VAR
      curx, cury : integer;
   BEGIN
      (*  Load the ScreenIntMap into the region given  *)
      FOR cury := y TO y + h DO
         FOR curx := x TO x + w DO
            IF NOT((curx >= cx) AND (curx <= cx + cw) AND (cury >= cy) AND (cury <= cy + ch)) THEN
               IF (getpixel(curx, cury) <> ord(ScreenIntMap[curx - x, cury - y])) THEN
                  putpixel(curx, cury, ord(ScreenIntMap[curx - x, cury - y]));
   END;

PROCEDURE GetIntMapFromScreen(sx, sy, ix, iy, iw, ih : integer; VAR ScreenIntMap : IntMapField);
   VAR
      curx, cury : integer;
   BEGIN
      (*  Return the ScreenIntMap array  *)
      FOR curx := ix TO iw DO
         FOR cury := iy TO ih DO
            ScreenIntMap[curx, cury] := chr(getpixel(curx + sx, cury + sy));
   END;

PROCEDURE CopyIntMap(x1, y1, w, h, x2, y2 : integer; VAR NewIntMap : IntMapField; OldIntMap : IntMapField);
   VAR
      curx, cury : integer;
   BEGIN
      FOR curx := 0 TO w DO
         FOR cury := 0 TO h DO
            NewIntMap[curx + x1, cury + y1] := OldIntMap[curx + x2, cury + y2];
   END;

PROCEDURE IntersectRect(x1, y1, w1, h1, x2, y2, w2, h2 : integer; VAR xi, yi, wi, hi : integer; VAR Intersect : boolean);
   VAR
      curx, cury : integer;
      IntersectIntMap : PACKED ARRAY [0..IntMapWidth, 0..IntMapHeight] OF boolean;
   BEGIN
      Intersect := false;
      FOR cury := y1 TO y1 + h1 DO
         FOR curx := x1 TO x1 + w1 DO
            IF (curx >= x2) AND (curx <= x2 + w2) AND (cury >= y2) AND (cury <= y2 + h2) THEN
               BEGIN
                  IntersectIntMap[curx - x1, cury - y1] := true;
                  Intersect := true;
               END
            ELSE
               IntersectIntMap[curx - x1, cury - y1] := false;

      IF Intersect THEN
         BEGIN
            Intersect := false;
            curx := 0;
            cury := 0;
            REPEAT
               IF IntersectIntMap[curx, cury] THEN
                  Intersect := true
               ELSE
                  IF (curx + 1) > w1 THEN
                     BEGIN
                        curx := 0;
                        cury := cury + 1;
                        IF cury > h1 THEN
                           BEGIN
                              writeln('IntersectRect Internal Failure');
                              Intersect := true;
                           END;
                     END
                  ELSE
                     curx := curx + 1;
            UNTIL Intersect;

            IF cury <= h1 THEN
               BEGIN
                  xi := curx;
                  yi := cury;

                  curx := curx + 1;
                  Intersect := false;
                  REPEAT
                     IF curx > w1 THEN
                        BEGIN
                           curx := curx - 1;
                           Intersect := true;
                        END
                     ELSE
                        IF IntersectIntMap[curx, cury] = false THEN
                           BEGIN
                              curx := curx - 1;
                              Intersect := true;
                           END
                        ELSE
                           curx := curx + 1;
                  UNTIL Intersect;

                  wi := curx - xi;

                  cury := cury + 1;
                  curx := xi;
                  Intersect := false;
                  REPEAT
                     IF cury > h1 THEN
                        BEGIN
                           cury := cury - 1;
                           Intersect := true;
                        END
                     ELSE
                        IF IntersectIntMap[curx, cury] = false THEN
                           BEGIN
                              cury := cury - 1;
                              Intersect := true;
                           END
                        ELSE
                           cury := cury + 1;
                  UNTIL Intersect;

                  hi := cury - yi;
                  xi := xi + x1;
                  yi := yi + y1;
               END;
         END;
   END;


PROCEDURE MoveIntMap(x1, y1, w1, h1, x2, y2, w2, h2 : integer; IntMap : IntMapField; VAR OldIntMap : IntMapField);
   VAR
      curx, cury : integer;
      Intersect : boolean;
      xi, yi, wi, hi : integer;
      NewIntMap : IntMapField;
   BEGIN
      IntersectRect(x2, y2, w2, h2, x1, y1, w1, h1, xi, yi, wi, hi, Intersect);
      IF Intersect THEN
         BEGIN
            GetIntMapFromScreen(x2, y2, 0, 0, w2, h2, NewIntMap);
            CopyIntMap(xi - x2, yi - y2, wi, hi, xi - x1, yi - y1, NewIntMap, OldIntMap);
            ClippedEraseRegion(x1, y1, w1, h1, xi, yi, wi, hi, OldIntMap);
            PasteIntMap(x2, y2, w2, h2, IntMap, NewIntMap);
            OldIntMap := NewIntMap;
         END
      ELSE
         BEGIN
            GetIntMapFromScreen(x2, y2, 0, 0, w2, h2, NewIntMap);
            EraseRegion(x1, y1, w1, h1, OldIntMap);
            PasteIntMap(x2, y2, w2, h2, IntMap, NewIntMap);
            OldIntMap := NewIntMap;
         END;
   END;

PROCEDURE RotateIntMap(x, y : integer; VAR w, h : integer; VAR IntMap : IntMapField; RotateLeft : boolean);
   VAR
      NewIntMap : IntMapField;
      curx, cury : integer;
      newx, newy : integer;
      Temp : integer;
   BEGIN
      NewIntMap := IntMap;
      newy := y;

      IF RotateLeft THEN
         FOR curx := x + w DOWNTO x DO
            BEGIN
               newx := x;
               FOR cury := y TO y + h DO
                  BEGIN
                     NewIntMap[newx, newy] := IntMap[curx, cury];
                     newx := newx + 1;
                  END;
               newy := newy + 1;
            END
      ELSE
         FOR curx := x TO x + w DO
            BEGIN
               newx := x;
               FOR cury := y + h DOWNTO y DO
                  BEGIN
                     NewIntMap[newx, newy] := IntMap[curx, cury];
                     newx := newx + 1;
                  END;
               newy := newy + 1;
            END;

      Temp := w;
      w := h;
      h := Temp;

      IntMap := NewIntMap;
   END;

PROCEDURE TitleScreen;
   BEGIN
      (*  Food chain title  *)
      SetBkColor(blue);
      SetTextStyle(1, 0, 7);
      SetColor(yellow);
      OutTextXY(145, 60, 'Food Chain');

      (*  Description of project  *)
      SetTextStyle(3, 0, 3);
      SetColor(yellow);
      OutTextXY(110, 260, 'In the first scene, a fish eats worms.');
      OutTextXY(88, 290, 'In the second scene, a cat eats the fish.');
      OutTextXY(130, 320, 'In the last scene, Alf eats the cat.');
      Delay(2000);
   END;

PROCEDURE Credits;
   VAR
      LCV : integer;
      IntMap : IntMapField;
      ScreenIntMap : IntMapField;
      x, y, w, h : integer;
   BEGIN
      (*  Food chain title  *)
      SetGraphMode(2);
      SetColor(Black);
      SetFillStyle(1, Cyan);
      FloodFill(42, 89, Cyan);
      FOR LCV := 0 TO 32 DO
         Arc(LCV * 20 + 10, 292, 180, 0, 10);
      SetFillStyle(1, Blue);
      FloodFill(42, 400, Black);
      SetTextStyle(1, 0, 7);
      SetColor(yellow);
      OutTextXY(188, 100, 'Credits');

      (*  Description of project  *)
      SetTextStyle(3, 0, 3);
      SetColor(yellow);
      OutTextXY(120, 360, 'Fish eating worms by Cris Gonzalez');
      OutTextXY(110, 390, 'Cat eats fish by Steven Lawrance');
      OutTextXY(130, 420, 'Alf eats cat by Julie Andrews');

      (*  Move fish  *)
      x := 23;
      y := 390;
      LoadIntMap('a:fishr.imp ', IntMap, w, h);
      GetIntMapFromScreen(x, y, 0, 0, w, h, ScreenIntMap);
      FOR LCV := 1 TO 40 DO
         BEGIN
            MoveIntMap(x, y, w, h, x + 4, y, w, h, IntMap, ScreenIntMap);
            x := x + 4;
         END;

      RotateIntMap(0, 0, w, h, IntMap, left);
      MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

      FOR LCV := 1 TO 34 DO
         BEGIN
            MoveIntMap(x, y, w, h, x, y - 5, w, h, IntMap, ScreenIntMap);
            y := y - 5;
         END;

      RotateIntMap(0, 0, w, h, IntMap, right);
      MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

      RotateIntMap(0, 0, w, h, IntMap, right);
      MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

      FOR LCV := 1 TO 34 DO
         BEGIN
            MoveIntMap(x, y, w, h, x, y + 5, w, h, IntMap, ScreenIntMap);
            y := y + 5;
         END;

      delay(1500);
      EraseRegion(x, y, w, h, ScreenIntMap);
   END;

(*  Put the individual parts in at this point using
    control KR.
    Call each person's driver from the indicated position in my driver.
              Where the procedures are called will determine in which
              quadrant they are drawn.  Pay attention to the comments
              in the driver to determine the quadrants.  DO NOT DELETE
              anything from my driver.

                                                                     *)
 {**********************************************************

NAME: CRIS GONZALEZ
PERIOD: 4TH

DATE ASSIGNED:May 10, 1995
PROGRAM NAME:Graphics
PURPOSE: to make a graphic of the food chain, my part being
         a fish eating worms
ALGORITHM:  1.0
            2.0

**********************************************************}

Procedure Drawworms;
VAR worm : integer;
    seaweed : integer;
   

 (*****************************************************************)
             (* Here begins the code for graphics*)
begin
   SetFillSTYLE (1,9);
   BAR (0,0, 319, 239);
   worm:= 12;
   setcolor (12);
   SetFillSTYlE (1,12);
   Circle (275, 175, 15);
   Circle (280, 146, 15);
   Circle (255, 198, 15);
   Circle (279, 116, 15);
   Circle (275, 87, 15);                  (* body *)
   FloodFill (275, 175, 12);
   FloodFill (277, 150, 12);
   Floodfill (255, 198, 12);
   FloodFill (279, 120, 12);
   Floodfill (275, 87, 12);
   setcolor (8);
   Setfillstyle (1, 8);
   Line (273, 70, 265, 50);
   Line (273, 70, 280, 50);
   Circle (270, 80, 2);
   Circle (280, 80, 2);       (* eyes and mouth *)
   circle (275, 93, 4);
   Floodfill (269, 80, 8);
   Floodfill (280, 80, 8);
   Floodfill (275, 93, 8);

   (***********tongue*********)
   setcolor (13);
   SetFillSTYlE (1,13);
   Arc (0, 239, 0, 90, 140);
   line (0, 100, 140, 239);
   Floodfill (130, 200, 13);
    
   (*************second worm************)
   setcolor (12);
   SetFillSTYlE (1,12);
   Circle (100, 90, 14);
   Circle (95, 118, 14);
   Circle (92, 147, 14);
   Circle (96, 175, 14);                {da body o da second worm}
   Circle (90, 203, 14);
   FloodFill (100, 90, 12);
   Floodfill (95, 118, 12);
   Floodfill (92, 147, 12);
   Floodfill (96, 175, 12);
   Floodfill (90, 203, 12);
   setcolor (8);
   Setfillstyle (1, 8);
   line (93, 78, 82, 65);
   line (107, 78, 119, 65);
   Circle (99, 85, 2);
   Circle (91, 85, 2);
   Floodfill (99, 85, 8);
   Floodfill (91, 85, 8);
   Fillellipse (95, 95, 3, 6);
   (**************mouth********************)

   setcolor (10);
   SetFillSTYlE (1,10);
   line (0, 100, 150, 0);
   line (0, 100, 140, 239);
   line (0, 239, 140, 239);   (*********the mouth*******)
   Floodfill (1, 1, 10);
   Floodfill (100, 220, 10);



   (***********teeth***********)


   setcolor (6);
   SetFillSTYlE (1,6);
   line (88, 45, 115, 75);
   line (115, 75, 105, 31);
   line (88, 45, 105, 31);
   floodfill (90, 46, 6);  (*********end o one**********)
   line (105, 31, 140, 60);
   line (140, 60, 140, 7);
   line (140, 7, 105, 31);
   floodfill (120, 42, 6); (***********end o second*******)
   line (140, 7, 170, 45);
   line (170, 45, 170, 0);
   line (140, 7, 153, 0);
   line (153, 0, 170, 0);
   floodfill (145, 9, 6); (************end o third********)
   line (88, 45, 85, 85);
   line (85, 85, 58, 61);
   line (58, 61, 153, 0);
   floodfill (66, 63, 6); (*************endo o fourth*****)
   line (58, 61, 0, 100);
   line (58, 61, 45, 105);
   line (45, 105, 0, 100);
   floodfill (5, 100, 6);
   (**********text*********)
   {Outtext ('This is a fishie');
   SetTextstyle (1, 150, 140);
   Outtext ('These are worms being eaten');}
   


END;
(***************************************************************)
               (* here begins the technical stuff *)
PROCEDURE CRISDRIVER;
   begin
      SetGraphMode(2);
      Drawworms;
   end;

{ ***********************************************************************

         NAME: Steven Lawrance
         PERIOD: 4th


         DATE ASSIGNED: May 4, 1995
         PROGRAM NAME: Graphics Project
         PURPOSE: A cat eats a fish

         ALGORITHM: On attached pages

  *********************************************************************** }

PROCEDURE MakeKittyCatEatFish;
   PROCEDURE DrawBGIBackground(SunX, SunY : integer; SunHappy : boolean);
      VAR
         LCV : integer;
      BEGIN
         (*  Set the screen color to cyan  *)
         SetFillStyle(1, Cyan);
         SetColor(Cyan);
         Bar(0, 0, 319, 239);

         (*  Draw the land  *)
         SetColor(Black);
         Line(130, 144, 319, 144);
         Line(130, 145, 319, 145);
         Line(97, 239, 130, 144);
         Line(98, 239, 130, 145);
         SetFillStyle(1, Brown);
         FloodFill(300, 200, Black);

         (*  Draw the water  *)
         SetColor(Black);
         FOR LCV := 0 TO 5 DO
            Arc(LCV * 20 + 10, 172, 180, 0, 10);
         SetFillStyle(1, Blue);
         FloodFill(42, 189, Black);

         (*  Draw the clouds  *)
         Ellipse(50, 50, 0, 360, 40, 20);
         Ellipse(150, 50, 0, 360, 30, 23);
         SetColor(White);
         SetFillStyle(1, White);
         FloodFill(50, 50, Black);
         FloodFill(150, 50, Black);
      END;

   PROCEDURE DrawSun(Happy : boolean);
      BEGIN
         (*  Erase region  *)
         SetColor(Black);
         SetFillStyle(1, Cyan);
         Bar(232, 4, 319, 60);

         (*  Draw sun  *)
         SetColor(Black);
         Circle(274, 36, 26);
         Line(269, 26, 269, 32);
         Line(277, 26, 277, 32);

         (*  Draw the yellow  *)
         SetFillStyle(1, Yellow);
         FloodFill(274, 36, Black);

         (*  Draw mouth  *)
         IF Happy THEN
            Arc(274, 36, 180, 360, 11)
         ELSE
            Circle(273, 44, 5);
      END;

   PROCEDURE AnimateCat;
      VAR
         x, y, w, h, LCV : integer;
         IntMap, ScreenIntMap : IntMapField;

      PROCEDURE DrawBody(x, y, body, paw : integer);
         PROCEDURE DrawPaw(x, y : integer);
            BEGIN
               SetFillStyle(1, paw);
               Circle(x, y + 42, 4);
               FloodFill(x, y + 42, body);
            END;
         BEGIN
            (*  Draw the cat's body  *)
            SetColor(body);
            Line(x + 14, y + 25, x + 54, y + 25);
            Line(x + 54, y + 25, x + 67, y + 10);
            Line(x + 54, y + 25, x + 62, y + 38);
            Line(x + 54, y + 25, x + 49, y + 38);
            Line(x + 14, y + 25, x + 14, y + 20);
            Line(x + 14, y + 25, x +  8, y + 38);
            Line(x + 14, y + 25, x + 22, y + 38);
            DrawPaw(x + 62, y);
            DrawPaw(x + 49, y);
            DrawPaw(x + 8, y);
            DrawPaw(x + 22, y);
         END;
      BEGIN
         (*  Load the Cat's face  *)
         x := 238;
         y := 97;
         LoadIntMap('a:cat.imp   ', IntMap, w, h);
         GetIntMapFromScreen(x, y, 0, 0, w, h, ScreenIntMap);

         (*  Move the cat  *)
         FOR LCV := 1 TO 44 DO
            BEGIN
               MoveIntMap(x, y, w, h, x - 2, y, w, h, IntMap, ScreenIntMap);
               DrawBody(x, y, cyan, cyan);
               DrawBody(x - 2, y, black, white);
               x := x - 2;
            END;
      END;

   PROCEDURE AnimateFish;
      VAR
         IntMap : IntMapField;
         ScreenIntMap : IntMapField;
         x, y, w, h : integer;
         LCV : integer;
      BEGIN
         x := 23;
         y := 195;
         LoadIntMap('a:fishr.imp ', IntMap, w, h);
         GetIntMapFromScreen(x, y, 0, 0, w, h, ScreenIntMap);
         FOR LCV := 1 TO 24 DO
            BEGIN
               delay(50);
               MoveIntMap(x, y, w, h, x + 2, y, w, h, IntMap, ScreenIntMap);
               x := x + 2;
            END;

         RotateIntMap(0, 0, w, h, IntMap, left);
         MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

         FOR LCV := 1 TO 34 DO
            BEGIN
               delay(50);
               MoveIntMap(x, y, w, h, x, y - 5, w, h, IntMap, ScreenIntMap);
               y := y - 5;
            END;

         RotateIntMap(0, 0, w, h, IntMap, right);
         MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

         FOR LCV := 1 TO 27 DO
            BEGIN
               delay(50);
               MoveIntMap(x, y, w, h, x + 3, y, w, h, IntMap, ScreenIntMap);
               x := x + 3;
            END;

         RotateIntMap(0, 0, w, h, IntMap, right);
         MoveIntMap(x, y, h, w, x, y, w, h, IntMap, ScreenIntMap);

         FOR LCV := 1 TO 15 DO
            BEGIN
               delay(50);
               MoveIntMap(x, y, w, h, x, y + 4, w, h, IntMap, ScreenIntMap);
               y := y + 4;
            END;

         delay(1500);
         EraseRegion(x, y, w, h, ScreenIntMap);
      END;

   PROCEDURE DrawMeow;
      BEGIN
         (*  Draw the meow thing  *)
         SetColor(black);
         Ellipse(230, 89, 0, 360, 36, 20);
         SetFillStyle(1, white);
         FloodFill(230, 89, black);
         SetTextStyle(2, 0, 8);
         MoveTo(200, 75);
         OutText('Meow!');
      END;

   BEGIN
      (*  Draw the scenery  *)
      DrawBGIBackground(0, 0, true);
      DrawSun(true);

      (*  Draw the cat and animate it  *)
      AnimateCat;

      (*  Load the fish and animate it  *)
      AnimateFish;

      (*  Draw speech bubble with "Meow!"  *)
      DrawMeow;

      (*  Draw the sun with a worried face  *)
      DrawSun(false);
   END;

PROCEDURE StevenDriver;
   BEGIN
      MakeKittyCatEatFish;
   END;

PROCEDURE JulieADriver ;

BEGIN


{********************************************************************}

{ This is to outline the quadrant in use }

Rectangle ( 0,0,  319,239 ) ;

{********************************************************************}

SetColor ( 7 ) ;
Ellipse (50,65,75,70,20,20  ) ;
Circle ( 45,55,5 ) ;
Circle ( 58,55,5 ) ;
SetColor  ( 8 ) ;
Rectangle ( 48,65,53,67 ) ;
SetColor ( 15 ) ;
Line ( 20,70,48,65 ) ;
Line ( 20,75,48,65 ) ;
Line ( 20,80,48,65 ) ;
Line ( 48,65,70,75 ) ;
Line ( 48,65,80,70 ) ;

Line ( 49,66,49,73 ) ;
Line ( 51,66,51,73 ) ;

SetColor ( 7 ) ;
Arc ( 75,65,195,223,24 ) ;
Arc ( 34,71,180,360,15 ) ;



SetColor ( 7 ) ;
Line ( 40,40,50,20) ;
LIne ( 50,20,55,40 ) ;

Line ( 60,40,65,20 ) ;
Line ( 65,20,75,60 ) ;


{ This is the body }

Ellipse ( 75,96,306,300,36,18) ;


{ This is the feet }

SetFillStyle ( 1,7 ) ;
Line ( 50,110,50,125 ) ;
Line ( 57,110,57,125 ) ;
Ellipse ( 51,130,306,300,7,5 ) ;
FloodFill ( 51,130,7 ) ;

Line ( 66,112,66,125 ) ;
Line ( 73,112,73,125 ) ;
Ellipse ( 67,129,306,300,6,4 ) ;
FloodFill ( 67,129,7 ) ;

Line ( 90,112,90,125 ) ;
Line ( 95,112,95,125 ) ;
Ellipse ( 91,130,306,300,7,5 ) ;
FloodFill ( 91,130,7 ) ;

Line ( 102,109,102,125 ) ;
Line ( 107,107,107,125 ) ;
Ellipse ( 103,128,306,300,6,4 ) ;
FloodFill ( 103,128,7 ) ;

{********************************************************************}

{ This set of graphics is going to be Alf }

{ This is the head }

SetColor ( 6 ) ;
Ellipse ( 200,90,306,300,50,69 ) ;

Line ( 170,30,197,10 ) ;       { These are the ears }
Line ( 197,10,197,23 ) ;

Line ( 197,23,215,8 ) ;
Line ( 215,8,238,39 ) ;

Ellipse ( 180,60,306,300,10,15 ) ;   { These are the eyes }
Ellipse ( 215,60,306,300,10,15 ) ;

SetColor ( 14 ) ;
Ellipse ( 180,60,306,300,5,13 ) ;
FloodFill ( 180,60,14 ) ;

Ellipse ( 215,60,306,300,5,13 ) ;
FloodFill ( 215,60,14 ) ;

{ This is the nose }

SetColor ( 6 ) ;
Circle ( 195,80,6 ) ;
Circle ( 195,84,6 ) ;
Circle ( 195,88,6 ) ;
Circle ( 195,92,6 ) ;
Circle ( 195,96,6 ) ;


{ This is the mouth }

Ellipse ( 195,130,306,300,25,10 ) ;

SetColor ( 15 ) ;
Rectangle ( 185,120,190,128 ) ;
Rectangle ( 190,120,195,128 ) ;
Rectangle ( 195,120,200,128 ) ;

readln ;


    END; { This is the end of the program }


(*************  Mrs. Annis' driver Part  ***************************)
Procedure Driver;
Var
  GrMode, GrDriver, GrError: integer;

Begin
  GrDriver := VGA;
  GrMode := 2;
  InitGraph (GrDriver, GrMode, '');
  GrError := GraphResult;
  If GrError <> GrOk
      then writeln ('Error')
      else
         begin

         (* call the procedure to do the opening screen at this point*)

            TitleScreen;

            delay (3000);

                   (* Upper Left Quadrant   *)
           setviewport(0,0,GetMaxX div 2, GetMaxY div 2,true);
           (* call the procedure for upper left quadrant at
              this point in the program                      *)

           CrisDriver;

           Delay (3000);



                    (* Upper Right Quadrant  *)
           setviewport(GetMaxX div 2 + 1,0, GetMaxX , GetMaxY div 2, true);

           (* call the procedure for upper right quadrant at
              this point in the program                      *)

           StevenDriver;

           Delay (3000);


                     (* Lower Right Quadrant   *)
           setviewport(GetMaxX div 2 + 1, GetMaxY div 2 + 1, GetMaxX, GetMaxY, true);

           (* call the procedure for lower right quadrant at
              this point in the program                      *)

           JulieADriver;

           delay (3000);


                     (* Lower Left Quadrant (none)  *)
{           setviewport(0,GetMaxY div 2 + 1, GetMaxX div 2 + 1, GetMaxY,true);}

           (* call the procedure for lower left quadrant at
              this point in the program                      *)

{           Person4JohnStill;                      }

{           Delay (3000);  }

           (* call the procedure for the credits at this point *)

           Credits;
           delay (3000);
         end;
      readln;
      CloseGraph;
    end;
BEGIN
  driver;
END.
